intelmq.bots.experts.cymru_whois package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.experts.cymru_whois package

## Submodules

## intelmq.bots.experts.cymru_whois.expert module

`intelmq.bots.experts.cymru_whois.expert.` `BOT`

  alias of `intelmq.bots.experts.cymru_whois.expert.CymruExpertBot`

class `intelmq.bots.experts.cymru_whois.expert.` `CymruExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `init`()
  `process`()

## intelmq.bots.experts.cymru_whois.lib module

Reference: https://team-cymru.com/community-services/ip-asn-mapping/#dns

If the query returns more than one network, we select the more specific one. See https://github.com/certtools/intelmq/issues/543

class `intelmq.bots.experts.cymru_whois.lib.` `Cymru`

  Bases: `object`

  static `query`(ip)

## Module contents